<?php
/**
 * @package     Joomla.Installation
 * @subpackage  Controller
 *
 * @copyright   Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

use Joomla\Registry\Registry;
use Sellacious\Config\ConfigHelper;

defined('_JEXEC') or die;

/**
 * Controller class to install the sample data for the Joomla Installer.
 *
 * @since  1.7.2
 */
class InstallationControllerActivationRetrieve extends JControllerBase
{
	/**
	 * Execute the controller.
	 *
	 * @return  void
	 *
	 * @since   1.7.2
	 */
	public function execute()
	{
		/** @var InstallationApplicationWeb $app */
		$app     = $this->getApplication();
		$sitekey = $this->input->getString('sitekey');

		if ($sitekey)
		{
			try
			{
				$activated = $this->retrieve($sitekey);

				if ($activated)
				{
					$view = InstallationHtmlHelper::getStep('license', 1);

					$app->redirect('index.php?view=' . $view);
				}
			}
			catch (Exception $e)
			{
				$app->enqueueMessage($e->getMessage(), 'error');
			}
		}

		$app->redirect('index.php?view=license');
	}

	/**
	 * Activate the software from the passed license key from jarvis in URL
	 *
	 * @param   string  $sitekey  The supplied sitekey
	 *
	 * @return  bool
	 *
	 * @throws  Exception
	 *
	 * @since   1.7.2
	 */
	public function retrieve($sitekey)
	{
		$model   = new InstallationModelSetup;
		$options = $model->getOptions();

		$post = array();

		$post['sitekey']       = $sitekey;
		$post['sitename']      = $options['site_name'];
		$post['siteurl']       = trim(JUri::root(), '\\/');
		$post['version']       = S_VERSION_CORE;
		$post['site_template'] = 'NA';

		$http = JHttpFactory::getHttp();
		$resp = $http->post(JARVIS_SITE . '/index.php?option=com_jarvis&task=site.validate&format=json', $post);

		if ($resp->code != 200)
		{
			throw new Exception(JText::_('COM_SELLACIOUS_ACTIVATION_COMMUNICATION_FAILURE'));
		}

		$response = new Registry($resp->body);

		if ($response->get('status') != 1)
		{
			throw new Exception($response->get('message'));
		}

		if (!$response->get('data.registered'))
		{
			throw new Exception(JText::_('COM_SELLACIOUS_ACTIVATION_UNREGISTERED_LICENSE_KEY'));
		}

		if ($response->get('data.modified'))
		{
			throw new Exception(JText::_('COM_SELLACIOUS_ACTIVATION_INVALID_LICENSE_KEY'));
		}

		$license = array_replace(array(), $post, (array) $response->get('data'));

		$model->storeOptions(array('license' => $license));

		return $response->get('data.active') == 1;
	}
}
