<?php
/**
 * @package     Joomla.Installation
 * @subpackage  Controller
 *
 * @copyright   Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

use Sellacious\Cache\CacheHelper;

defined('_JEXEC') or die;

/**
 * Controller class to install the sample data for the Joomla Installer.
 *
 * @since  1.7.2
 */
class InstallationControllerInstallCache extends JControllerBase
{
	/**
	 * Execute the controller.
	 *
	 * @return  void
	 *
	 * @since   1.7.2
	 */
	public function execute()
	{
		// Get the application
		/** @var InstallationApplicationWeb $app */
		$app = $this->getApplication();

		// Check for request forgeries.
		JSession::checkToken() or $app->sendJsonResponse(new Exception(JText::_('JINVALID_TOKEN'), 403));

		// Get the setup model.
		$model = new InstallationModelSetup;

		// Get the options from the session
		$options = $model->getOptions();

		// Get the database model.
		$db = new InstallationModelDatabase;

		$r = new stdClass;

		if (!$db->initialise($options))
		{
			$r->view = 'database';

			$app->sendJsonResponse($r);
		}

		$return = $this->setCache();

		// Check if the cache was updated
		if (!$return)
		{
			$r->view = 'database';

			$app->sendJsonResponse($r);
		}

		// All Good
		$r->view = 'install';

		$app->sendJsonResponse($r);
	}

	/**
	 * Put the cache file in place after installation
	 *
	 * @return  bool
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	protected function setCache()
	{
		defined('JPATH_SELLACIOUS') or define('JPATH_SELLACIOUS', JPATH_SITE . '/sellacious');
		defined('JPATH_SELLACIOUS_DIR') or define('JPATH_SELLACIOUS_DIR', 'sellacious');

		$src     = JPATH_INSTALLATION . '/resources/products.scdb';
		$session = JFactory::getSession();
		$secret  = $session->get('config.values.secret');

		// Import sellacious library
		JLoader::import('sellacious.loader');

		if (file_exists($src))
		{
			$name = CacheHelper::getFilename('products', $secret);

			JFolder::create(dirname($name));
			JFile::copy($src, $name);
		}

		return true;
	}
}
