<?php
/**
 * @package     Joomla.Installation
 * @subpackage  Controller
 *
 * @copyright   Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/**
 * Controller class to install the sample data for the Joomla Installer.
 *
 * @since  1.7.2
 */
class InstallationControllerInstallSellacious extends JControllerBase
{
	/**
	 * Execute the controller.
	 *
	 * @return  void
	 *
	 * @since   1.7.2
	 */
	public function execute()
	{
		// Get the application
		/** @var InstallationApplicationWeb $app */
		$app = $this->getApplication();

		// Check for request forgeries.
		JSession::checkToken() or $app->sendJsonResponse(new Exception(JText::_('JINVALID_TOKEN'), 403));

		// Get the setup model.
		$model = new InstallationModelSetup;

		// Get the options from the session
		$options = $model->getOptions();

		// Get the database model.
		$db = new InstallationModelDatabase;

		$r = new stdClass;

		if (!$db->initialise($options))
		{
			$r->view = 'database';

			$app->sendJsonResponse($r);
		}

		// Import sellacious library
		JLoader::import('sellacious.loader');

		$return = $db->installSellaciousConfig($options);

		// Check if the config was updated
		if (!$return)
		{
			$r->view = 'database';

			$app->sendJsonResponse($r);
		}

		$return = $db->installSellaciousLicense($options);

		// Check if the license was saved
		if (!$return)
		{
			$r->view = 'license';

			$app->sendJsonResponse($r);
		}

		// All Good
		$r->view = 'install';

		$app->sendJsonResponse($r);
	}
}
