<?php
/**
 * @package	Joomla.Installation
 *
 * @copyright  Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license	GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/** @var JDocumentHtml $this */

// Output as HTML5
$this->setHtml5(true);

// Load the JavaScript behaviors
JHtml::_('bootstrap.framework');
JHtml::_('formbehavior.chosen', 'select');
JHtml::_('behavior.keepalive');
JHtml::_('behavior.formvalidator');
JHtml::_('behavior.core');
JHtml::_('behavior.polyfill', array('event'), 'lt IE 9');

// Add installation js
JHtml::_('script', 'installation/template/js/installation.js', array('version' => 'auto'));

// Add html5 shiv
JHtml::_('script', 'jui/html5.js', array('version' => 'auto', 'relative' => true, 'conditional' => 'lt IE 9'));

// Add Stylesheets
JHtml::_('bootstrap.loadCss', true, $this->direction);
JHtml::_('stylesheet', 'installation/template/css/template.css', array('version' => 'auto'));
JHtml::_('stylesheet', 'installation/template/css/custom-bs3.css', array('version' => 'auto'));

// JS and CSS for licensing in Sellacious
JHtml::_('script', 'installation/template/js/util.activation.js', array('version' => 'auto'));
JHtml::_('script', 'installation/template/js/activation.plans.js', array('version' => 'auto'));
JHtml::_('script', 'installation/template/js/activation.keyform.js', array('version' => 'auto'));
JHtml::_('stylesheet', 'installation/template/css/activation.register.css', array('version' => 'auto'));
JHtml::_('stylesheet', 'sellacious/templates/sellacious/css/font-awesome.min.css', array('version' => 'auto'));

// Load JavaScript message titles
JText::script('ERROR');
JText::script('WARNING');
JText::script('NOTICE');
JText::script('MESSAGE');

// Add strings for JavaScript error translations.
JText::script('JLIB_JS_AJAX_ERROR_CONNECTION_ABORT');
JText::script('JLIB_JS_AJAX_ERROR_NO_CONTENT');
JText::script('JLIB_JS_AJAX_ERROR_OTHER');
JText::script('JLIB_JS_AJAX_ERROR_PARSE');
JText::script('JLIB_JS_AJAX_ERROR_TIMEOUT');

// Load the JavaScript translated messages
JText::script('INSTL_PROCESS_BUSY');
JText::script('INSTL_FTP_SETTINGS_CORRECT');
JText::script('INST_FORM_INVALID_MESSAGE');

JFactory::getLanguage()->load('com_sellacious', JPATH_SITE . '/components/com_sellacious');
JFactory::getLanguage()->load('com_sellacious', JPATH_SITE);

// Sellacious license messages
JText::script('COM_SELLACIOUS_VALIDATION_FORM_FAILED');
JText::script('COM_SELLACIOUS_LICENSE_ACTIVATION_OTP_RESENT');
JText::script('COM_SELLACIOUS_LICENSE_ACTIVATION_OTP_INVALID');
JText::script('COM_SELLACIOUS_LICENSE_ACTIVATION_CHECKING_IN');
JText::script('COM_SELLACIOUS_LICENSE_ACTIVATION_CHECKING_NOW');
JText::script('COM_SELLACIOUS_LICENSE_ACTIVATION_SERVER_ERROR');
JText::script('COM_SELLACIOUS_LICENSE_ACTIVATION_NOT_ACTIVATED');

// Add script options
$this->addScriptOptions('system.installation', array('url' => JRoute::_('index.php')));
$this->addScriptOptions('sellacious.jarvis_site', JARVIS_SITE);
?>
<!DOCTYPE html>
<html lang="<?php echo $this->language; ?>" dir="<?php echo $this->direction; ?>">
	<head>
		<jdoc:include type="head" />
		<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.5.0/css/all.css" integrity="sha384-B4dIYHKNBt8Bc12p+WXckhzcICo0wtJAoU8YZTY5qE0Id1GSseTk6S+L3BlXeVIU" crossorigin="anonymous">
		<!--[if lt IE 9]><script src="<?php echo JUri::root(true); ?>/media/jui/js/html5.js"></script><![endif]-->
	</head>
	<body data-basepath="<?php echo JUri::root(true); ?>">
		<div class="body-wrap">
			<!-- Header -->
			<div class="header">
				<img src="<?php echo $this->baseurl; ?>/template/images/sellacious-large.png" alt="Sellacious" style="width: 160px;"/>
				<h5>
					<?php $doc_link = '<a href="https://www.sellacious.com/documentation-v2" target="_blank" rel="noopener noreferrer">' . "click here" . '</a>'; ?>
					<?php echo JText::sprintf('JGLOBAL_ISFREESOFTWARE', $doc_link); ?>
				</h5>
			</div>
			<!-- Container -->
			<div class="container">
				<jdoc:include type="message" />
				<div id="javascript-warning">
					<noscript>
						<div class="alert alert-error">
							<?php echo JText::_('INSTL_WARNJAVASCRIPT'); ?>
						</div>
					</noscript>
				</div>
				<div id="container-installation">
					<jdoc:include type="component" />
				</div>
			</div>
		</div>
	</body>
</html>
