/**
 * @version     1.6.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2018 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
let SellaciousPlanActivation = function () {

	this.api = null;

	return this;
};

jQuery(function ($) {
	SellaciousPlanActivation.prototype = {
		init: function (wrapper) {
			let $this = this;
			$this.wrapper = $(wrapper);

			$this.loadPlans();

			$this.wrapper
				.on('click', '.btn-activate-free', function () {
					$this.register();
				})
				.on('click', '.btn-buynow', function () {
					let url = Joomla.getOptions('sellacious.jarvis_site') + '/index.php';
					let form = $('<form>', {action: url, method: 'post', target: '_top'});
					$('<input>', {type: 'hidden', name: 'option', value: 'com_jarvis'}).appendTo(form);
					$('<input>', {type: 'hidden', name: 'task', value: 'site.addToCart'}).appendTo(form);
					$('<input>', {type: 'hidden', name: 'format', value: 'json'}).appendTo(form);
					$('<input>', {type: 'hidden', name: 'siteurl', value: $this.wrapper.data('siteurl')}).appendTo(form);
					$('<input>', {type: 'hidden', name: 'baseurl', value: $this.wrapper.data('baseurl')}).appendTo(form);
					$('<input>', {type: 'hidden', name: 'uid', value: $(this).data('product-id')}).appendTo(form);
					$('<input>', {type: 'hidden', name: 'price', value: $(this).data('price')}).appendTo(form);
					form.appendTo($('body')).submit().remove();
				});
		},

		loadPlans: function () {
			let $this = this;
			$.ajax({
				url: Joomla.getOptions('sellacious.jarvis_site') + '/index.php',
				type: 'GET',
				cache: false,
				data: {
					option: 'com_jarvis',
					task: 'subscription.getPlansHtml',
					site_id: null,
				}
			}).done(function (response) {
				$this.wrapper.html(response.replace(/(templates\/sellacious\/)/g, 'template/'));
			}).fail(function (xhr) {
				let err = '<div style="text-align: center; margin: 50px; color: #d00000; font-weight: bold; font-size: 18px;">' +
					'Failed to load the available plans. Please try again.</div>';
				$this.wrapper.html(err);
				console.log(xhr.responseText);
			});
		},

		register: function () {
			const data = {
				name: keyActivation.wizard.find('#jform_name').val(),
				email: keyActivation.wizard.find('#jform_email').val(),
				siteurl: keyActivation.wizard.find('#jform_siteurl').val(),
				sitename: keyActivation.wizard.find('#jform_sitename').val(),
				version: keyActivation.wizard.find('#jform_version').val(),
				site_template: keyActivation.wizard.find('#jform_template').val() || 'NA',
				choices: ['install']
			};

			Joomla.loadingLayer("show");

			// When starting new registration clear old api instance
			keyActivation.api = new SellaciousActivationApi();
			keyActivation.api.setCredential(data.name, data.email)
				.setSiteurl(data.siteurl)
				.setSitename(data.sitename)
				.setVersion(data.version)
				.setTemplate(data.template)
				.setChoices(data.choices);

			keyActivation.api.register()
				.done(function (response) {
					if (response.status === 1) {
						keyActivation.wizard.find('#jform_sitekey').val(response.data.sitekey);
						if (keyActivation.api.activated) {
							// Already activated. Thanks! But we are in tab 1, move forward!
							Joomla.loadingLayer("hide");
							keyActivation.navStep(2);
							keyActivation.setLicense();
						} else {
							// OTP sent! Switch tab
							keyActivation.api.setLicense()
								.done(function (response) {
									if (response.error === false) {
										keyActivation.navStep(2);
										keyActivation.startDetect();
									} else {
										Joomla.renderMessages({warning: [response.message]});
									}
								})
								.always(function () {
									Joomla.loadingLayer("hide");
								});
						}
					} else {
						Joomla.loadingLayer("hide");
						Joomla.renderMessages({warning: [response.message]});
					}
				})
				.always(function (data, status, xhr) {
					if (status !== 'success') {
						Joomla.loadingLayer("hide");
					}
				});
		}
	};
});
